# exclude plugin .so from provides
%global __provides_exclude_from ^%{_libdir}/%{name}/(plugins|views)/.*\\.so$

#squidf:from Fedora: cmake flag -DRAWSPEED_ENABLE_LTO needs GCC >= 9 and EL8 has GCC 8
%global use_rawspeed 1
%if %{use_rawspeed}
%global _use_rawspeed_lto "ON"
%endif

%define git_name darktable
%define _darkdir /usr/local/%{git_name}/

#squidf: lua 5.4 isn't supported yet in Mageia. Should be in darktable 3.8.
%bcond_with systemlua

Name:           darktable
Version:        4.2.1
#%%define subrel  0
Release:        %mkrel 1
Summary:        Open source photography workflow application and RAW developer
Group:          Graphics/Photography
License:        GPLv3+
Url:            https://www.darktable.org
Source0:        https://github.com/darktable-org/darktable/releases/download/release-%{version}/darktable-%{version}.tar.xz
#squidf:fix compiler syntax error and unknown option for MGA8
Patch5: darktable-4.2.0-compiler_fix.patch

BuildRequires:  cmake(sdl2)
BuildRequires:  cmake
BuildRequires:  cups-devel
BuildRequires:  gnome-doc-utils
BuildRequires:  intltool
BuildRequires:  libgomp-devel
BuildRequires:  llvm
BuildRequires:  perl-Image-ExifTool
%if %{with systemlua}
BuildRequires:  lua-devel
%endif
BuildRequires:  pkgconfig(colord)
BuildRequires:  pkgconfig(colord-gtk)
BuildRequires:  pkgconfig(dbus-glib-1)
#squidf: to enable ISOBMFF required to support cr3 files
BuildRequires:  pkgconfig(exiv2) >= 0.27.4
BuildRequires:  pkgconfig(flickcurl)
BuildRequires:  pkgconfig(GraphicsMagick)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(lensfun)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libgphoto2)
#squidf:to enable HEIF support
BuildRequires:  pkgconfig(libheif)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(OpenEXR)
BuildRequires:  pkgconfig(osmgpsmap-1.0)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(pugixml)
BuildRequires:  xsltproc
#squidf:iso-codes dependency not mandatory, just optional / recommended
BuildRequires:  iso-codes >= 3.66
#squidf:from Fedora
BuildRequires:  devel(libgmic(64bit))
BuildRequires:  opencl-headers

# Only supports 64-bit architectures.
ExclusiveArch: x86_64 aarch64

#squidf:iso-codes dependency not mandatory, just optional / recommended
Requires:   iso-codes >= 3.66
#squidf: to enable ISOBMFF required to support cr3 files
Requires:   lib64exiv2_27 >= 0.27.4

#squidf: from openSUSE
# Some CSS themes suggest to use the the Roboto font family
# https://github.com/darktable-org/darktable/releases/tag/release-3.0.0
Recommends: roboto-fontface-fonts


%if ! %{with systemlua}
Provides:	bundled(lua) = 5.4.0
%endif

#squidf:from Fedora
# Concerning rawspeed bundled library, see
# https://fedorahosted.org/fpc/ticket/550#comment:9
%if %{use_rawspeed}
Provides: bundled(rawspeed)
%endif

%description
Darktable is an open source photography workflow application and
RAW developer. A virtual lighttable and darkroom for photographers.
It manages your digital negatives in a database, lets you view them
through a zoomable lighttable and enables you to develop raw images
and enhance them.

Advanced users may be interested in the optional %{name}-tools-noise
and %{name}-tools-basecurve packages for command line tools.

#squidf:all tools below added from Fedora
%package tools-noise
Summary:        Noise profiling tool to add support for new cameras in darktable
Group:          Graphics/Photography
Requires:       gnuplot
Requires:       ImageMagick

%description tools-noise
The darktable noise command line tool can be used to generate noise profiles for
new cameras which are not included yet in darktable. You can then contribute
these noise profiles to the darktable project.

The provided tools are:
%{_libexecdir}/%{name}/tools/%{name}-gen-noiseprofile
%{_libexecdir}/%{name}/tools/%{name}-noiseprofile

See https://pixls.us/articles/how-to-create-camera-noise-profiles-for-darktable/
for details.

%package tools-basecurve
Summary:        Basecurve tool for darktable
Group:          Graphics/Photography
Requires:       dcraw
Requires:       ImageMagick
Requires:       perl-Image-ExifTool

%description tools-basecurve
The darktable basecurve command line tool.
Another option to solve the same problem might be the darktable-chart module
from the darktable package.

The provided tools are:
%{_libexecdir}/%{name}/tools/%{name}-curve-tool
%{_libexecdir}/%{name}/tools/%{name}-curve-tool-helper

See https://www.darktable.org/2013/10/about-basecurves/ for details.

%prep
%setup -q -n %{name}-%{version}
%autopatch -p1


%build
#squidf:add noise tool, basecurve tool, drawspeed, build_type and prefix
%cmake \
  -DBINARY_PACKAGE_BUILD:BOOL=ON \
  -DDONT_USE_INTERNAL_LUA:BOOL=%{?with_systemlua:ON}%{!?with_systemlua:OFF} \
  -DCMAKE_BUILD_TYPE:STRING=Release \
  -DPROJECT_VERSION="%{version}" \
  -DBUILD_NOISE_TOOLS=ON \
  -DBUILD_CURVE_TOOLS=ON \
  -DRAWSPEED_ENABLE_LTO=%{_use_rawspeed_lto}
%cmake_build

%install
%cmake_install

#handle docs in files section
%{__rm} -rf %{buildroot}%{_docdir}

#to find libdarktable.so without rpath.
%{__mkdir_p} %{buildroot}%{_sysconfdir}/ld.so.conf.d
cat > %{buildroot}%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf << EOF
%{_libdir}/%{name}
EOF

#squidf: pixmaps icon for Gnome
%{__mkdir_p} %{buildroot}/usr/share/pixmaps
ln -s %{_iconsdir}/hicolor/scalable/apps/%{name}.svg %{buildroot}%{_datadir}/pixmaps/%{name}.svg

#squidf: from 4.2.1, desktop and appdata installation
%{__mkdir_p} %{buildroot}/usr/share/applications
%{__install} -m 644 build/share/darktable/org.darktable.darktable.desktop %{buildroot}/%{_datadir}/applications
%{__mkdir_p} %{buildroot}/usr/share/metainfo
%{__install} -m 644 build/share/metainfo/org.darktable.darktable.appdata.xml %{buildroot}/%{_metainfodir}

%find_lang %{name} --with-man --all-name

%files -f %{name}.lang
%doc AUTHORS README.md RELEASE_NOTES.md
%license LICENSE
%config %{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf
%{_bindir}/%{name}
%{_bindir}/%{name}-chart
%{_bindir}/%{name}-cli
%{_bindir}/%{name}-cltest
%{_bindir}/%{name}-cmstest
%{_bindir}/%{name}-generate-cache
%{_bindir}/%{name}-rs-identify
%{_datadir}/applications/*.desktop
%{_metainfodir}/*.appdata.xml
%{_datadir}/%{name}/
%{_iconsdir}/hicolor/*/apps/%{name}*
%{_libdir}/%{name}/
%{_mandir}/man1/%{name}.1.*
%{_mandir}/man1/%{name}-cli.1.*
%{_mandir}/man1/%{name}-cltest.1.*
%{_mandir}/man1/%{name}-cmstest.1.*
%{_mandir}/man1/%{name}-generate-cache.1.*

%{_datadir}/pixmaps/%{name}.svg

%files tools-noise
%dir %{_libexecdir}/darktable
%dir %{_libexecdir}/darktable/tools
%{_libexecdir}/darktable/tools/darktable-gen-noiseprofile
%{_libexecdir}/darktable/tools/darktable-noiseprofile
%{_libexecdir}/darktable/tools/profiling-shot.xmp
%{_libexecdir}/darktable/tools/subr.sh

%files tools-basecurve
%{_libexecdir}/darktable/tools/darktable-curve-tool
%{_libexecdir}/darktable/tools/darktable-curve-tool-helper
%{_datadir}/%{name}/tools/basecurve/


%changelog
* Mon Feb 27 2023 squidf <squid-f> 4.2.1-1
- Update version to 4.2.1

* Fri Dec 23 2022 squidf <squid-f> 4.2.0-0
- Update version to 4.2.0

* Sat Sep 24 2022 squidf <squid-f> 4.0.1-0
- Update version to 4.0.1
- Update tools descriptions

* Sun Jul 3 2022 squidf <squid-f> 4.0.0-0
- Update version to 4.0.0
- Don't recommend tools-noise and tools-basecurve

* Sun Feb 13 2022 squidf <squid-f> 3.8.1-0.2
- Recommend tools-noise and tools-basecurve of the same version

* Sun Feb 13 2022 squidf <squid-f> 3.8.1-0.1
- Enforce exiv2 >= 0.27.4 to activate ISOBMFF support

* Sat Feb 12 2022 squidf <squid-f> 3.8.1-0 
- Update version to 3.8.1
- Use mkrel 0 to allow replacement by official MGA repo version, if any
- Deprecated DT_CLONE patch
- Add missing basecurve tool package
- Recommend tools-noise and tools-basecurve

* Fri Jan 21 2022 squidf <squid-f> 3.8.0-1 
- Update version to 3.8.0
- Add rawspeed_lto
- Add noise tool
- Add HEIF support
- Add gmic support
- Add pixmaps icon for Gnome
- Allow openCL compilation test
- Provides exiftool through perl-Image-ExifTool
- Provides lua 5.4
- Fix compiler option typo or unknown for Mageia 8
